==> edge-login-ui-rn-3.4.1.tgz: package/lib/components/abSpecific/LogoImageHeader.js <==
import * as React from 'react';
import { Image, TouchableWithoutFeedback, View } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import * as Assets from '../../assets/';
import { lstrings } from '../../common/locales/strings';
import { useHandler } from '../../hooks/useHandler';
import { useTheme } from '../services/ThemeContext';
export function LogoImageHeader(props) {
    const { branding } = props;
    const { primaryLogo = Assets.LOGO_BIG, primaryLogoCallback } = branding;
    const theme = useTheme();
    const styles = getStyles(theme);
    const taps = React.useRef(0);
    const handlePress = useHandler(() => {
        if (primaryLogoCallback != null) {
            taps.current++;
            if (taps.current > 4) {
                primaryLogoCallback();
                taps.current = 0;
            }
            if (taps.current === 1) {
                setTimeout(() => (taps.current = 0), 2000);
            }
        }
    });
    return (React.createElement(TouchableWithoutFeedback, { onPress: handlePress },
        React.createElement(View, { style: styles.container },
            React.createElement(Image, { accessibilityHint: lstrings.app_logo_hint, source: primaryLogo, style: styles.image, resizeMode: "contain" }))));
}
const getStyles = cacheStyles((theme) => ({
    container: {
        alignItems: 'center',
        justifyContent: 'space-around',
        paddingBottom: theme.rem(1.5),
        width: '100%'
    },
    image: {
        height: theme.rem(2.75),
        overflow: 'visible',
        resizeMode: 'contain'
    }
}));

==> edge-login-ui-rn-3.17.0.tgz: package/lib/components/abSpecific/LogoImageHeader.js <==
import * as React from 'react';
import { Image, View } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import * as Assets from '../../assets/';
import { lstrings } from '../../common/locales/strings';
import { useHandler } from '../../hooks/useHandler';
import { EdgeTouchableWithoutFeedback } from '../common/EdgeTouchableWithoutFeedback';
import { useTheme } from '../services/ThemeContext';
export function LogoImageHeader(props) {
    const { branding } = props;
    const { primaryLogo = Assets.LOGO_BIG, primaryLogoCallback } = branding;
    const theme = useTheme();
    const styles = getStyles(theme);
    const taps = React.useRef(0);
    const handlePress = useHandler(() => {
        if (primaryLogoCallback != null) {
            taps.current++;
            if (taps.current > 4) {
                primaryLogoCallback();
                taps.current = 0;
            }
            if (taps.current === 1) {
                setTimeout(() => (taps.current = 0), 2000);
            }
        }
    });
    return (React.createElement(EdgeTouchableWithoutFeedback, { onPress: handlePress },
        React.createElement(View, { style: styles.container },
            React.createElement(Image, { accessibilityHint: lstrings.app_logo_hint, source: primaryLogo, style: styles.image, resizeMode: "contain" }))));
}
const getStyles = cacheStyles((theme) => ({
    container: {
        alignItems: 'center',
        justifyContent: 'space-around',
        paddingBottom: theme.rem(1.5),
        width: '100%'
    },
    image: {
        height: theme.rem(2.75),
        overflow: 'visible',
        resizeMode: 'contain'
    }
}));
